StartCtx

Struct StartCtx 

pub struct StartCtx<W>
where W: Widget,
{ /* private fields */ }

Implementations

Source

impl<W> StartCtx<W>
where W: Widget,

pub fn widget_id(&self) -> WidgetId

pub fn instance_id(&self) -> InstanceId

pub fn post(&mut self, message: W::Message)

pub fn request_render(&mut self)

Marks the current frame dirty and wakes the host if this is the first pending redraw.

Repeated calls before the host consumes the pending frame are coalesced into one redraw.

pub fn scheduler(&mut self) -> Scheduler<'_, W::Message>

Returns the scheduler owned by the current widget instance. All timers created here are cleared when the instance stops or is disposed.

pub fn tasks(&mut self) -> Tasks<'_, W::Message>

Returns the task backend owned by the current widget instance. All tasks created here are canceled when the instance stops or is disposed.