UpdateCtx

Struct UpdateCtx 

pub struct UpdateCtx<W>
where W: Widget,
{ /* private fields */ }

Implementations

Source

impl<W> UpdateCtx<W>
where W: Widget,

pub fn widget_id(&self) -> WidgetId

pub fn instance_id(&self) -> InstanceId

pub fn post(&mut self, message: W::Message)

pub fn request_render(&mut self)

pub fn scheduler(&mut self) -> Scheduler<'_, W::Message>

Returns the scheduler owned by the current widget instance. All timers created here are cleared when the instance stops or is disposed.

pub fn tasks(&mut self) -> Tasks<'_, W::Message>

Returns the task backend owned by the current widget instance. All tasks created here are canceled when the instance stops or is disposed.