pub struct UpdateCtx<W>where
W: Widget,{ /* private fields */ }Implementations
Sourceimpl<W> UpdateCtx<W>where
W: Widget,
impl<W> UpdateCtx<W>where
W: Widget,
pub fn widget_id(&self) -> WidgetId
pub fn instance_id(&self) -> InstanceId
pub fn post(&mut self, message: W::Message)
Sourcepub fn request_render(&mut self)
pub fn request_render(&mut self)
Marks the current frame dirty and wakes the host if this is the first pending redraw.
Repeated calls before the host consumes the pending frame are coalesced into one redraw.